Learn R Programming

moodleR (version 1.0.5)

moodleR-package: moodleR: Helper Functions to Work with 'Moodle' Data

Description

logo

A collection of functions to connect to a 'Moodle' database, cache relevant tables locally and generate learning analytics. 'Moodle' is an open source Learning Management System (LMS) developed by MoodleHQ. For more information about Moodle, visit https://moodle.org.

logo

A collection of functions to connect to a 'Moodle' database, cache relevant tables locally and generate learning analytics. 'Moodle' is an open source Learning Management System (LMS) developed by MoodleHQ. For more information about Moodle, visit https://moodle.org.

Arguments

Author

Maintainer: Aleksander Dietrichson dietrichson@gmail.com

Other contributors:

  • Chi Square Laboratories [copyright holder]

  • Darko Miletic [contributor]

  • Pablo Pagnone [contributor]

  • Alex Ondrus [contributor]

See Also